import { HTMLSelect } from "@jupyterlab/ui-components";
import * as React from "react";
import { AutoSizer, Column, Table } from "react-virtualized";
import { classes, style } from "typestyle";
import { GlobalStyle } from "./globalStyles";
/** React component for the package list */
export class CondaPkgList extends React.Component {
    constructor(props) {
        super(props);
    }
    render() {
        const rowGetter = ({ index }) => this.props.packages[index];
        const iconRender = ({ rowData }) => {
            if (rowData.version_installed) {
                if (rowData.version_selected === "none") {
                    return React.createElement("i", { className: Style.StatusRemove });
                }
                else if (rowData.version_selected !== rowData.version_installed) {
                    return React.createElement("i", { className: Style.StatusUpdate });
                }
                return React.createElement("i", { className: Style.StatusInstalled });
            }
            else if (rowData.version_selected !== "none") {
                return React.createElement("i", { className: Style.StatusInstalled });
            }
            return React.createElement("i", { className: Style.StatusAvailable });
        };
        const isSelected = (index) => {
            const rowData = this.props.packages[index];
            if (rowData.version_installed) {
                if (rowData.version_selected === "none") {
                    return true;
                }
                else if (rowData.version_selected !== rowData.version_installed) {
                    return true;
                }
            }
            else if (rowData.version_selected !== "none") {
                return true;
            }
            return false;
        };
        const nameRender = ({ rowData }) => {
            if (rowData.home && rowData.home.length > 0) {
                // TODO possible enhancement - open in a JupyterLab Panel
                return (React.createElement("a", { className: Style.Link, href: rowData.home, onClick: (evt) => evt.stopPropagation(), target: "_blank", rel: "noopener noreferrer" },
                    rowData.name,
                    " ",
                    React.createElement("i", { className: "fa fa-external-link" })));
            }
            return React.createElement("span", null, rowData.name);
        };
        const changeRender = ({ rowData }) => (React.createElement(HTMLSelect, { className: Style.VersionSelection, value: rowData.version_selected, onClick: (evt) => {
                evt.stopPropagation();
            }, onChange: (evt) => this.props.onPkgChange(rowData, evt.target.value), iconProps: {
                icon: React.createElement("span", { className: "jp-MaterialIcon jp-DownCaretIcon bp3-icon" })
            }, "aria-label": "Package versions", minimal: true },
            React.createElement("option", { key: "-3", value: "none" }, "Remove"),
            !rowData.version_installed && (React.createElement("option", { key: "-2", value: "" }, "Install")),
            rowData.updatable && (React.createElement("option", { key: "-1", value: "" }, "Update")),
            rowData.version.map((v) => (React.createElement("option", { key: v, value: v }, v)))));
        return (React.createElement("div", { className: Style.TableContainer },
            React.createElement(AutoSizer, { disableHeight: true }, ({ width }) => (React.createElement(Table, { className: Style.Table, headerClassName: Style.Header, headerHeight: 29, height: this.props.height, onRowClick: ({ rowData }) => this.props.onPkgClick(rowData), rowClassName: ({ index }) => {
                    if (index >= 0) {
                        return index % 2 === 0
                            ? Style.RowEven(isSelected(index))
                            : Style.RowOdd(isSelected(index));
                    }
                }, rowCount: this.props.packages.length, rowGetter: rowGetter, rowHeight: 40, width: width },
                React.createElement(Column, { className: Style.CellStatus, dataKey: "status", cellRenderer: iconRender, disableSort: true, label: "", flexShrink: 0, width: 20 }),
                React.createElement(Column, { className: Style.CellName, dataKey: "name", cellRenderer: nameRender, disableSort: true, label: "Name", width: 200, flexGrow: 1, flexShrink: 1 }),
                this.props.hasDescription && (React.createElement(Column, { className: Style.CellSummary, dataKey: "summary", disableSort: true, label: "Description", width: 250, flexGrow: 5, flexShrink: 5 })),
                React.createElement(Column, { cellRenderer: ({ rowData }) => (React.createElement("span", { className: rowData.updatable
                            ? classes(Style.Updatable, Style.Cell)
                            : Style.Cell }, rowData.version_installed)), dataKey: "version_installed", disableSort: true, label: "Version", flexShrink: 0, width: 90 }),
                React.createElement(Column, { className: Style.Cell, dataKey: "version_selected", cellRenderer: changeRender, disableSort: true, label: "Change to", flexShrink: 0, width: 120 }),
                React.createElement(Column, { className: Style.Cell, dataKey: "channel", disableSort: true, flexGrow: 1, label: "Channel", flexShrink: 1, width: 120 }))))));
    }
}
CondaPkgList.defaultProps = {
    hasDescription: false,
    packages: []
};
var Style;
(function (Style) {
    Style.TableContainer = style({});
    Style.Table = style({});
    Style.Header = style({
        color: "var(--jp-ui-font-color1)",
        fontWeight: "bold",
        fontSize: "var(--jp-ui-font-size2)",
        textAlign: "left"
        // $nest: {
        //   '&:hover div': {
        //     fontWeight: 600,
        //     color: 'var(--jp-ui-font-color0)'
        //   },
        //   '&:focus div': {
        //     outline: 'none'
        //   },
        //   '&:active div': {
        //     fontWeight: 600,
        //     color: 'var(--jp-ui-font-color0)'
        //   }
        // }
    });
    Style.RowEven = (selected) => style({
        background: selected ? "var(--jp-brand-color3)" : "unset",
        $nest: {
            "&:hover": {
                backgroundColor: "var(--jp-layout-color3)"
            }
        }
    });
    Style.RowOdd = (selected) => style({
        background: selected
            ? "var(--jp-brand-color3)"
            : "var(--jp-layout-color2)",
        $nest: {
            "&:hover": {
                backgroundColor: "var(--jp-layout-color3)"
            }
        }
    });
    Style.CellStatus = style({
        padding: "0px 2px"
    });
    Style.CellName = style({ whiteSpace: "nowrap" });
    Style.CellSummary = style({
        alignSelf: "flex-start",
        whiteSpace: "normal"
    });
    Style.Cell = style({
        whiteSpace: "nowrap"
    });
    Style.SortButton = style({
        transform: "rotate(180deg)",
        marginLeft: "10px",
        color: "var(--jp-ui-font-color2)",
        border: "none",
        backgroundColor: "var(--jp-layout-color0)",
        fontSize: "var(--jp-ui-font-size1)"
    });
    Style.Link = style({
        $nest: {
            "&:hover": {
                textDecoration: "underline"
            }
        }
    });
    Style.StatusAvailable = classes("fa", "fa-square-o", "fa-fw", style(GlobalStyle.FaIcon, {
        verticalAlign: "middle"
    }));
    Style.StatusInstalled = classes("fa", "fa-check-square", "fa-fw", style(GlobalStyle.FaIcon, {
        verticalAlign: "middle",
        color: "var(--jp-brand-color1)"
    }));
    Style.StatusUpdate = classes("fa", "fa-external-link-square", "fa-fw", style(GlobalStyle.FaIcon, {
        verticalAlign: "middle",
        color: "var(--jp-accent-color1)"
    }));
    Style.StatusRemove = classes("fa", "fa-minus-square", "fa-fw", style(GlobalStyle.FaIcon, {
        verticalAlign: "middle",
        color: "var(--jp-error-color1)"
    }));
    Style.Updatable = style({
        color: "var(--jp-brand-color0)",
        $nest: {
            "&::before": {
                content: "'↗️'",
                paddingRight: 2
            }
        }
    });
    Style.VersionSelection = style({
        width: "100%"
    });
})(Style || (Style = {}));
//# sourceMappingURL=CondaPkgList.js.map